function [ a ] = simple_plot( X )

%close all

%% LOAD MODEL AND DATA
Model = 'Macrophage_simple';
optModel = IQMmodel(strcat(Model,'.txt'));
IQMmakeMEXmodel(optModel,Model);
[paramNames] = IQMparameters(optModel);
[reactionNames] = IQMreactions(optModel);
initCon = IQMinitialconditions(optModel);

LoadData;
LoadDrugData;
TNF_Timepoints = DRUGDATA.timepoints;
TNF_Timepoints2 = DRUGDATA.timepoints2;
X = exp(X);

%% LOAD PARAMS
%values=load('allGoodValues.dat');
%ind=find(values(:,1)<min(values(:,1))*1.001,1);
%all_p = values(ind,:);
%X = all_p(2:end-3);

%scale_exp1 = all_p(end-2)
%scale_exp2 = all_p(end-1)
%scale_exp3 = all_p(end)

%% DEFINE COLORS
LPS0 = [0,0,0];
LPS100 = [0.5,0,0];
LPS1000 = [1,0,0];
dexa03 = [0,0,0.5];
dexa03_pre = [0,0,0.8];
dexa3 = [0,0.5,0];
dexa3_pre1 = [0,0.5,1];
dexa3_pre2 = [0.5,0.5,0.7];
dexa3_pre3 = [1,0.5,0.4];

%% SIMULATIONS


%X(end) = 0;
X = [X, 0, 0];

ss_simulation = IQMPsimulate(Model, 700, initCon, paramNames, X);
ss_simulation.statevalues(end, end) = 0; %TNFa 0 at experiment start

%%%%%%%%%% DEXAMETHASONE EXPERIMENTS FROM MARIA LIND MASTER THESIS %%%%%%
%ONLY LPS
X(end) = 0;
X(end-1) = 0;
LPS_0_simulation = IQMPsimulate(Model, 24, ss_simulation.statevalues(end,:), paramNames, X);
X(end-1) = 10;
LPS_10_simulation = IQMPsimulate(Model, 24, ss_simulation.statevalues(end,:), paramNames, X);
X(end-1) = 50;
LPS_50_simulation = IQMPsimulate(Model, 24, ss_simulation.statevalues(end,:), paramNames, X);
X(end-1) = 100;
LPS_100_simulation = IQMPsimulate(Model, 24, ss_simulation.statevalues(end,:), paramNames, X);
X(end-1) = 250;
LPS_250_simulation = IQMPsimulate(Model, 24, ss_simulation.statevalues(end,:), paramNames, X);
X(end-1) = 500;
LPS_500_simulation = IQMPsimulate(Model, 24, ss_simulation.statevalues(end,:), paramNames, X);
X(end-1) = 1000;
LPS_1000_simulation = IQMPsimulate(Model, 24, ss_simulation.statevalues(end,:), paramNames, X);

figure(9)
errorbar(EXPDATA.lps, EXPDATA.tnfa, EXPDATA.sem, 'ks','LineWidth', 1.5, 'MarkerFaceColor', 'k', 'MarkerSize', 4);
hold on
plot(EXPDATA.lps, [LPS_10_simulation.variablevalues(end,2),LPS_50_simulation.variablevalues(end,2),LPS_100_simulation.variablevalues(end,2),LPS_250_simulation.variablevalues(end,2),LPS_500_simulation.variablevalues(end,2),LPS_1000_simulation.variablevalues(end,2)], 'k', 'LineWidth', 2);
title('LPS dose-response');
xlabel('LPS (np/ml)');
ylabel('TNF-\alpha');
set(gca,'FontSize',18);

%scale day-to-day differences between sets of data linearly
time_scale_exp3 = round(EXPDATA.timepoints*1000/24)+1;
scale_exp3=lscov([LPS_0_simulation.variablevalues(time_scale_exp3(1:end),2); LPS_100_simulation.variablevalues(time_scale_exp3(1:end),2); LPS_1000_simulation.variablevalues(time_scale_exp3(1:end),2)], [EXPDATA.tnfaControl(1:end)'; EXPDATA.tnfa100(1:end)'; EXPDATA.tnfa1000(1:end)']);

figure(10)
hold on
errorbar(EXPDATA.timepoints, EXPDATA.tnfa1000, EXPDATA.sem1000,'s',  'Color', LPS1000, 'LineWidth', 1.5, 'MarkerFaceColor', LPS1000, 'MarkerSize', 4);
errorbar(EXPDATA.timepoints, EXPDATA.tnfa100, EXPDATA.sem100, 's', 'Color', LPS100, 'LineWidth', 1.5, 'MarkerFaceColor', LPS100, 'MarkerSize', 4);
errorbar(EXPDATA.timepoints, EXPDATA.tnfaControl, EXPDATA.semControl, 's', 'Color', LPS0, 'LineWidth', 1.5, 'MarkerFaceColor', LPS0, 'MarkerSize', 4);
plot(LPS_0_simulation.time, scale_exp3.*LPS_0_simulation.variablevalues(:,2), 'Color', LPS0, 'LineWidth', 2);
plot(LPS_100_simulation.time, scale_exp3.*LPS_100_simulation.variablevalues(:,2), 'Color', LPS100, 'LineWidth', 2);
plot(LPS_1000_simulation.time, scale_exp3.*LPS_1000_simulation.variablevalues(:,2), 'Color', LPS1000, 'LineWidth', 2);

axis([0, 25, 0, 500]);
title('LPS');
xlabel('Time (h)');
ylabel('TNF-\alpha');
set(gca,'FontSize',18);
LEG = legend('1000 uM LPS', '100 uM LPS', 'control', 'Location', 'northwest');
set(LEG,'FontSize',15);

%PRE-TREATMENT DEXA
X(end-1) = 0;
X(end) = 0.3;
Dexa_simulation_pre300 = IQMPsimulate(Model, 1, ss_simulation.statevalues(end,:), paramNames, X);
X(end) = 3;
Dexa_simulation_pre3000 = IQMPsimulate(Model, 1, ss_simulation.statevalues(end,:), paramNames, X);

%%addition of 100 ng/ml LPS
X(end-1) = 100;
X(end) = 0;
Dexa_simulation = IQMPsimulate(Model, 25, ss_simulation.statevalues(end,:), paramNames, X);
X(end) = 0.3;
Dexa_simulation_pre300.statevalues(end,end) = 0; %TNFa 
Model_simulation2 = IQMPsimulate(Model, 25, Dexa_simulation_pre300.statevalues(end ,:), paramNames, X);
X(end) = 3;
Dexa_simulation_pre3000.statevalues(end,end) = 0; %TNFa
Model_simulation3 = IQMPsimulate(Model, 25, Dexa_simulation_pre3000.statevalues(end, :), paramNames, X);
X(end) = 0.00;
Model_simulation4 = IQMPsimulate(Model, 25, Dexa_simulation_pre300.statevalues(end,:), paramNames, X);
X(end) = 0.0;
Model_simulation5 = IQMPsimulate(Model, 25, Dexa_simulation_pre3000.statevalues(end, :), paramNames, X);

time_scale_exp2 = round(DRUGDATA.timepoints*1000/24)+1;
scale_exp2=lscov([Dexa_simulation.variablevalues(time_scale_exp2,2); Model_simulation2.variablevalues(time_scale_exp2,2); Model_simulation3.variablevalues(time_scale_exp2,2); Model_simulation4.variablevalues(time_scale_exp2,2); Model_simulation5.variablevalues(time_scale_exp2,2)], [DRUGDATA.tnfa100Control'; DRUGDATA.tnfaLowdex'; DRUGDATA.tnfaHighdex'; DRUGDATA.tnfaLowdex_pre'; DRUGDATA.tnfaHighdex_pre']);

figure(2);
errorbar(DRUGDATA.timepoints, DRUGDATA.tnfa100Control, DRUGDATA.sem100Control, 's', 'Color', LPS100, 'LineWidth', 1.5, 'MarkerFaceColor', LPS100, 'MarkerSize', 4);
hold on
errorbar(DRUGDATA.timepoints, DRUGDATA.tnfaLowdex_pre, DRUGDATA.semLowdex_pre, 's', 'Color', dexa03_pre, 'LineWidth', 1.5, 'MarkerFaceColor', dexa03_pre, 'MarkerSize', 4);
errorbar(DRUGDATA.timepoints, DRUGDATA.tnfaHighdex_pre, DRUGDATA.semHighdex_pre, 's', 'Color', dexa3_pre3, 'LineWidth', 1.5, 'MarkerFaceColor', dexa3_pre3, 'MarkerSize', 4);
errorbar(DRUGDATA.timepoints, DRUGDATA.tnfaLowdex, DRUGDATA.semLowdex, 's', 'Color', dexa03, 'LineWidth', 1.5, 'MarkerFaceColor', dexa03, 'MarkerSize', 4);
errorbar(DRUGDATA.timepoints, DRUGDATA.tnfaHighdex, DRUGDATA.semHighdex, 's', 'Color', dexa3, 'LineWidth', 1.5, 'MarkerFaceColor', dexa3, 'MarkerSize', 4);
plot(Dexa_simulation.time, scale_exp2.*Dexa_simulation.variablevalues(:,2), 'Color', LPS100, 'LineWidth', 2);
plot(Model_simulation2.time, scale_exp2.*Model_simulation2.variablevalues(:,2),'Color', dexa03, 'LineWidth', 2);
plot(Model_simulation3.time, scale_exp2.*Model_simulation3.variablevalues(:,2),'Color', dexa3, 'LineWidth', 2);
plot(Model_simulation4.time, scale_exp2.*Model_simulation4.variablevalues(:,2),'Color', dexa03_pre, 'LineWidth', 2);
plot(Model_simulation5.time, scale_exp2.*Model_simulation5.variablevalues(:,2),'Color', dexa3_pre3, 'LineWidth', 2);

axis([0, 25, 0, 500]);
title('Dexamethasone + 100 uM LPS');
xlabel('Time (h)');
ylabel('TNF-\alpha');
set(gca,'FontSize',18);
LEG = legend('control', '0.3 uM dexa (removed)', '3 uM dexa (removed)', '0.3 uM dexa', '3 uM dexa', 'Location', 'northwest');
set(LEG,'FontSize',15);

%%%%%%%%%% DEXAMETHASONE EXPERIMENTS FROM MARIA LIND MASTER THESIS: LONG-TIME EFFECT %%%%%%

X = X(1:(end-2));
X = [X, 0, 3]; %% Addition of 3 ug Dexa for 1 hour, no LPS
one_hour_sim = IQMPsimulate(Model, 1, ss_simulation.statevalues(end, :), paramNames, X); 
one_hour_sim.statevalues(end,end) = 0; %TNFa = 0
X(end) = 0.0; %% 22 hours without dexa nor LPS
twentytwo_hour_sim = IQMPsimulate(Model, 22, one_hour_sim.statevalues(end,:), paramNames, X);
X(end-1) = 100; %% Trigger an inflammatory effect with LPS. 
twentytwo_hour_sim.statevalues(end,end) = 0; %%TNFa = 0
pre1_sim = IQMPsimulate(Model, 7, twentytwo_hour_sim.statevalues(end,:), paramNames, X);
X = X(1:(end-2));
X = [X, 0, 0.0];
sixteen_hour_sim = IQMPsimulate(Model, 16, one_hour_sim.statevalues(end,:), paramNames, X);
X = X(1:(end-2));
X = [X, 100, 0.0];
sixteen_hour_sim.statevalues(end,end) = 0; %TNFa = 0
pre2_sim = IQMPsimulate(Model, 7, sixteen_hour_sim.statevalues(end,:), paramNames, X);
X = X(1:(end-2));
X = [X, 100, 0.0];
pre3_sim = IQMPsimulate(Model, 7, one_hour_sim.statevalues(end,:), paramNames, X);
pre3_sim.variablevalues(round(TNF_Timepoints2 * 1000 / 7) + 1,2)

time_scale_exp2 = round(DRUGDATA.timepoints2*1000/24)+1;
scale_exp1=lscov([Dexa_simulation.variablevalues(time_scale_exp2,2); pre1_sim.variablevalues(time_scale_exp2,2); pre2_sim.variablevalues(time_scale_exp2,2); pre3_sim.variablevalues(time_scale_exp2,2)], [DRUGDATA.pre_control_tnfa'; DRUGDATA.pre1_tnfa'; DRUGDATA.pre2_tnfa'; DRUGDATA.pre3_tnfa']);

figure(3);
errorbar(DRUGDATA.timepoints2, DRUGDATA.pre_control_tnfa, DRUGDATA.pre_control_sem, 's', 'Color', LPS100, 'LineWidth', 1.5, 'MarkerFaceColor', LPS100, 'MarkerSize', 4);
hold on
errorbar(DRUGDATA.timepoints2, DRUGDATA.pre1_tnfa, DRUGDATA.pre1_sem, 's', 'Color', dexa3_pre1, 'LineWidth', 1.5, 'MarkerFaceColor', dexa3_pre1, 'MarkerSize', 4);
errorbar(DRUGDATA.timepoints2, DRUGDATA.pre2_tnfa, DRUGDATA.pre2_sem, 's', 'Color', dexa3_pre2, 'LineWidth', 1.5, 'MarkerFaceColor', dexa3_pre2, 'MarkerSize', 4);
errorbar(DRUGDATA.timepoints2, DRUGDATA.pre3_tnfa, DRUGDATA.pre3_sem, 's', 'Color', dexa3_pre3, 'LineWidth', 1.5, 'MarkerFaceColor', dexa3_pre3, 'MarkerSize', 4);
plot(Dexa_simulation.time, scale_exp1.*Dexa_simulation.variablevalues(:,2), 'Color', LPS100, 'LineWidth', 2);
plot(pre1_sim.time, scale_exp1.*pre1_sim.variablevalues(:,2), 'Color', dexa3_pre1, 'LineWidth', 2);
plot(pre2_sim.time, scale_exp1.*pre2_sim.variablevalues(:,2), 'Color', dexa3_pre2, 'LineWidth', 2);
plot(pre3_sim.time, scale_exp1.*pre3_sim.variablevalues(:,2), 'Color', dexa3_pre3, 'LineWidth', 2);
axis([0, 7, 0, 210]);
title('Pre-treatments with dexa');
xlabel('Time (h)');
ylabel('TNF-\alpha');
set(gca,'FontSize',18);
LEG = legend('control', 'pre1', 'pre2', 'pre3', 'Location', 'northwest');
set(LEG,'FontSize',15);

figure(89)
plot(1:7/1000:8, pre3_sim.statevalues(:,3), 'Color', dexa3_pre3, 'LineWidth', 2);
hold on
plot(16:7/1000:23, pre2_sim.statevalues(:,3), 'Color',dexa3_pre2, 'LineWidth', 2);
plot(22:7/1000:29, pre1_sim.statevalues(:,3), 'Color', dexa3_pre1, 'LineWidth', 2);
%plot(1:25/1000:26, Model_simulation5.statevalues(:,3), 'Color', dexa3_pre3, 'LineWidth', 2);
plot(0:0.001:1, one_hour_sim.statevalues(:,3), 'Color', LPS0, 'LineWidth', 2);
plot(1:15/1000:16, sixteen_hour_sim.statevalues(:,3), 'Color', LPS0, 'LineWidth', 2);
plot(1:21/1000:22, twentytwo_hour_sim.statevalues(:,3), 'Color', LPS0, 'LineWidth', 2);
plot(1:25/1000:26, Model_simulation3.statevalues(:,3), 'Color', dexa3, 'LineWidth', 2);

figure(101)
statenames = IQMstates(Model);
for i = 1:10
    subplot(4,3,i), plot(LPS_100_simulation.time, LPS_100_simulation.statevalues(:,i), 'Color', LPS100, 'LineWidth', 2);
    hold on
    subplot(4,3,i),plot(1:7/1000:8, pre3_sim.statevalues(:,i), 'Color', dexa3_pre3, 'LineWidth', 2);
    subplot(4,3,i),plot(16:7/1000:23, pre2_sim.statevalues(:,i), 'Color',dexa3_pre2, 'LineWidth', 2);
    subplot(4,3,i),plot(22:7/1000:29, pre1_sim.statevalues(:,i), 'Color', dexa3_pre1, 'LineWidth', 2);
    %subplot(4,3,i),plot(1:25/1000:26, Model_simulation3.statevalues(:,i), 'Color', dexa3, 'LineWidth', 2);
    subplot(4,3,i), plot(0:0.001:1, one_hour_sim.statevalues(:,i), 'Color', LPS0, 'LineWidth', 2);
    subplot(4,3,i),plot(1:15/1000:16, sixteen_hour_sim.statevalues(:,i), 'Color', LPS0, 'LineWidth', 2);
    subplot(4,3,i), plot(1:21/1000:22, twentytwo_hour_sim.statevalues(:,i), 'Color', LPS0, 'LineWidth', 2);
    subplot(4,3,i),plot(1:25/1000:26, Model_simulation2.statevalues(:,i), 'Color', dexa03, 'LineWidth', 2);
    subplot(4,3,i),plot(1:25/1000:26, Model_simulation4.statevalues(:,i), 'Color', dexa03_pre, 'LineWidth', 2);
    title(statenames(i))
end

figure(102)
statenames = IQMstates(Model);
for i = 1:10
    subplot(4,3,i), plot(LPS_100_simulation.time, LPS_100_simulation.reactionvalues(:,i), 'Color', LPS100, 'LineWidth', 2);
    hold on
    subplot(4,3,i),plot(1:7/1000:8, pre3_sim.reactionvalues(:,i), 'Color', dexa3_pre3, 'LineWidth', 2);
    subplot(4,3,i),plot(16:7/1000:23, pre2_sim.reactionvalues(:,i), 'Color',dexa3_pre2, 'LineWidth', 2);
    subplot(4,3,i),plot(22:7/1000:29, pre1_sim.reactionvalues(:,i), 'Color', dexa3_pre1, 'LineWidth', 2);
    subplot(4,3,i),plot(1:25/1000:26, Model_simulation3.reactionvalues(:,i), 'Color', dexa3, 'LineWidth', 2);
    subplot(4,3,i), plot(0:0.001:1, one_hour_sim.reactionvalues(:,i), 'Color', LPS0, 'LineWidth', 2);
    subplot(4,3,i),plot(1:15/1000:16, sixteen_hour_sim.reactionvalues(:,i), 'Color', LPS0, 'LineWidth', 2);
    subplot(4,3,i), plot(1:21/1000:22, twentytwo_hour_sim.reactionvalues(:,i), 'Color', LPS0, 'LineWidth', 2);
    subplot(4,3,i),plot(1:25/1000:26, Model_simulation2.reactionvalues(:,i), 'Color', dexa03, 'LineWidth', 2);
    subplot(4,3,i),plot(1:25/1000:26, Model_simulation4.reactionvalues(:,i), 'Color', dexa03_pre, 'LineWidth', 2);
    title(reactionNames(i))
end

a=1;
end