function [cost] = cost_simple(param, shouldIPlot)
 
    global EXPDATA
    global initCon
    global paramNames
    global Model
    global TNF_Timepoints
    global TNF_Timepoints2
    global DRUGDATA
    global FID


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%       SIMULATION

    param = exp(param);
 
    %%STEADY STATE SIMULATION (LPS = Dexa = 0)
    param = [param, 0, 0];
    try

    ss_simulation = IQMPsimulate(Model, 700, initCon, paramNames, param);
    ss_simulation.statevalues(end, end) = 0; %TNFa 0 at experiment start


%% LPS simulations

param(end) = 0;
param(end-1) = 0;
LPS_0_simulation = IQMPsimulate(Model, TNF_Timepoints, ss_simulation.statevalues(end,:), paramNames, param);
param(end-1) = 10;
LPS_10_simulation = IQMPsimulate(Model, TNF_Timepoints, ss_simulation.statevalues(end,:), paramNames, param);
param(end-1) = 50;
LPS_50_simulation = IQMPsimulate(Model, TNF_Timepoints, ss_simulation.statevalues(end,:), paramNames, param);
param(end-1) = 100;
LPS_100_simulation = IQMPsimulate(Model, TNF_Timepoints, ss_simulation.statevalues(end,:), paramNames, param);
param(end-1) = 250;
LPS_250_simulation = IQMPsimulate(Model, TNF_Timepoints, ss_simulation.statevalues(end,:), paramNames, param);
param(end-1) = 500;
LPS_500_simulation = IQMPsimulate(Model, TNF_Timepoints, ss_simulation.statevalues(end,:), paramNames, param);
param(end-1) = 1000;
LPS_1000_simulation = IQMPsimulate(Model, TNF_Timepoints, ss_simulation.statevalues(end,:), paramNames, param);
param(end-1) = 0;
doseresponseLPS = [LPS_10_simulation.variablevalues(end,2),LPS_50_simulation.variablevalues(end,2),LPS_100_simulation.variablevalues(end,2),LPS_250_simulation.variablevalues(end,2),LPS_500_simulation.variablevalues(end,2),LPS_1000_simulation.variablevalues(end,2)];

%% Dexamethasone simulations

% PRE-TREATMENT SIMULATIONS - macrophages are pre-treated with 0.3 or 3 ug
% Dexa for 1 hour
param(end) = 0.3;
Dexa_simulation_pre300 = IQMPsimulate(Model, 1, ss_simulation.statevalues(end,:), paramNames, param);
param(end) = 3;
Dexa_simulation_pre3000 = IQMPsimulate(Model, 1, ss_simulation.statevalues(end,:), paramNames, param);

% 0 uM DEXAMETHASONE SIMULATION (positive control), only 100 ng/ml LPS
param = param(1:(end-2));
param = [param, 100, 0];
Dexa_simulation1 = IQMPsimulate(Model, TNF_Timepoints, ss_simulation.statevalues(end,:), paramNames, param);

% 0.3 uM DEXAMETHASONE SIMULATION
param(end) = 0.3;
Dexa_simulation2 = IQMPsimulate(Model, TNF_Timepoints, ss_simulation.statevalues(end, :), paramNames, param);

% 3 uM DEXAMETHASONE SIMULATION
param(end) = 3;
Dexa_simulation3 = IQMPsimulate(Model, TNF_Timepoints, ss_simulation.statevalues(end, :), paramNames, param);

% 0.3 uM DEXAMETHASONE SIMULATION (pre-treatment)
param(end) = 0;
Dexa_simulation4 = IQMPsimulate(Model, TNF_Timepoints, Dexa_simulation_pre300.statevalues(end, :), paramNames, param);

% 3 uM DEXAMETHASONE SIMULATION (pre-treatment)
param(end) = 0;
Dexa_simulation5 = IQMPsimulate(Model, TNF_Timepoints, Dexa_simulation_pre3000.statevalues(end, :), paramNames, param);
   

%% Dexamethasone simulations
%Experiments with pre-treatment at different timepoints.
 
% % Control
param = param(1:(end-2));
param = [param, 100, 0];
Pre_control_simulation = IQMPsimulate(Model, TNF_Timepoints2, ss_simulation.statevalues(end,:), paramNames, param);

% % 1 hour stimulation with 3 ug dexa (pre-treatment)
param = param(1:(end-2));
param = [param, 0, 3];
one_hour_simulation = IQMPsimulate(Model, 1, ss_simulation.statevalues(end,:), paramNames, param);
one_hour_simulation.statevalues(end, end) = 0; %TNFa 0, buffer change

% % Pre-treatment 1
param(end) = 0;
twentytwo_hour_simulation = IQMPsimulate(Model, 22, one_hour_simulation.statevalues(end,:), paramNames, param);
param(end-1) = 100;
twentytwo_hour_simulation.statevalues(end, end) = 0; %TNFa 0 at experiment start
Pre1_simulation = IQMPsimulate(Model, TNF_Timepoints2, twentytwo_hour_simulation.statevalues(end,:), paramNames, param);

% % Pre-treatment 2
param(end-1) = 0;
sixteen_hour_simulation = IQMPsimulate(Model, 16, one_hour_simulation.statevalues(end,:), paramNames, param);
param(end-1) = 100;
sixteen_hour_simulation.statevalues(end, end) = 0; %TNFa 0 at experiment start
Pre2_simulation = IQMPsimulate(Model, TNF_Timepoints2, sixteen_hour_simulation.statevalues(end,:), paramNames, param);

% % Pre-treatment 3
Pre3_simulation = IQMPsimulate(Model, TNF_Timepoints2, one_hour_simulation.statevalues(end,:), paramNames, param);

    catch myError
    cost = 1e6;
    return 
    end

Control_simval = Pre_control_simulation.variablevalues(:,2);
Pre1_simval = Pre1_simulation.variablevalues(:,2);
Pre2_simval = Pre2_simulation.variablevalues(:,2);
Pre3_simval = Pre3_simulation.variablevalues(:,2);

Drug_simvalues1 = Dexa_simulation1.variablevalues(:,2);
Drug_simvalues2 = Dexa_simulation2.variablevalues(:,2);
Drug_simvalues3 = Dexa_simulation3.variablevalues(:,2);
Drug_simvalues4 = Dexa_simulation4.variablevalues(:,2);
Drug_simvalues5 = Dexa_simulation5.variablevalues(:,2);

%scale day-to-day differences between sets of data linearly
scale=lscov([Drug_simvalues1; Drug_simvalues2; Drug_simvalues3; Drug_simvalues4; Drug_simvalues5], [DRUGDATA.tnfa100Control'; DRUGDATA.tnfaLowdex'; DRUGDATA.tnfaHighdex'; DRUGDATA.tnfaLowdex_pre'; DRUGDATA.tnfaHighdex_pre']);

%validation data
cost1 = sum((DRUGDATA.pre_control_tnfa - scale.*Control_simval').^2 ./ (DRUGDATA.pre_control_sem).^2);
cost2 = sum((DRUGDATA.pre1_tnfa(3:end) - scale.*Pre1_simval(3:end)').^2 ./ (DRUGDATA.pre1_sem(3:end)).^2);
cost3 = sum((DRUGDATA.pre2_tnfa(3:end) - scale.*Pre2_simval(3:end)').^2 ./ (DRUGDATA.pre2_sem(3:end)).^2);
cost4 = sum((DRUGDATA.pre3_tnfa(3:end) - scale.*Pre3_simval(3:end)').^2 ./ (DRUGDATA.pre3_sem(3:end)).^2);

%estimation data
cost5 = sum((DRUGDATA.tnfa100Control(3:end) - scale.*Drug_simvalues1(3:end)').^2 ./ (DRUGDATA.sem100Control(3:end)).^2);
cost6 = sum((DRUGDATA.tnfaLowdex(4:end) - scale.*Drug_simvalues2(4:end)').^2 ./ (DRUGDATA.semLowdex(4:end)).^2);
cost7 = sum((DRUGDATA.tnfaHighdex(4:end) - scale.*Drug_simvalues3(4:end)').^2 ./ (DRUGDATA.semHighdex(4:end)).^2);
cost8 = sum((DRUGDATA.tnfaHighdex_pre(4:end) - scale.*Drug_simvalues5(4:end)').^2 ./ (DRUGDATA.semHighdex_pre(4:end)).^2);
cost9 = sum((DRUGDATA.tnfaLowdex_pre(4:end) - scale.*Drug_simvalues4(4:end)').^2 ./ (DRUGDATA.semLowdex_pre(4:end)).^2);

costLPS0 = sum((EXPDATA.tnfaControl(2:end) - LPS_0_simulation.variablevalues(2:end,2)').^2 ./ (EXPDATA.semControl(2:end)).^2);
costLPS100 = sum((EXPDATA.tnfa100(2:end) - LPS_100_simulation.variablevalues(2:end,2)').^2 ./ (EXPDATA.sem100(2:end)).^2);
costLPS1000 = sum((EXPDATA.tnfa1000(2:end) - LPS_1000_simulation.variablevalues(2:end,2)').^2 ./ (EXPDATA.sem1000(2:end)).^2);

costLPSdose = sum((EXPDATA.tnfa - doseresponseLPS).^2 ./ (EXPDATA.sem).^2);

%costTNF = cost1 + cost2 + cost3 + cost4 + cost5 + cost6 + cost7 + cost8 + cost9;
costTNF = cost5 + cost6 + cost7 + cost8 + cost9;
costLPS = costLPS0 + costLPS100 + costLPS1000;
cost = costTNF + costLPSdose + costLPS; %+ costextra;

%%          CHI-SQUARE TEST

if cost < 83
   format short
   fprintf(FID,'%4.10f %10.10f ',[cost, param(1:end-2), scale]); fprintf(FID,'\n');
end
 
end

