close all

%% LOAD MODEL AND DATA
Model = 'Macrophage_treatment';
optModel = IQMmodel(strcat(Model,'.txt'));
IQMmakeMEXmodel(optModel,Model);
paramNames = IQMparameters(optModel);
statenames = IQMstates(Model);
initCon = IQMinitialconditions(optModel);

%% DEFINE COLORS
LPS0 = [0,0,0]; %black
LPS100 = [230,159,0]./256; %orange
LPS1000 = [240,228,66]./256; %yellow
dexa03_pre = [204,121,167]./256; %purple pink
dexa03 = [213,94,0]./256; %red
dexa3_pre3 = [86,180,233]./256; %sky blue
dexa3 = [0,114,178]./256; %blue
dexa3_pre2 = [0,158,115]./256; %green
dexa3_pre1 = [80,0,0]./256; %brown

%% LOAD PARAMS
load values_alldata.mat

values = values_alldata;
thres = 69;

ind=find(values(:,1)<thres);

%select resolution (for speed select higher value)
res = 1000;

all_param = ones(round(size(ind,1)/res), size(values,2));
size(all_param)
l=1;

for i = 1:res:size(ind, 1)

    all_p = values(ind(i),:);
    X = all_p(2:end-1);
    
    scale = all_p(end);
    
    all_param(1+(i-1)/res,:) = all_p(:);
    
    X = [X, 0, 0];
    
    ss_simulation = IQMPsimulate(Model, 700, initCon, paramNames, X);
    ss_simulation.statevalues(end, end) = 0; %TNFa 0 at experiment start
    
    dose_LPS = 1;
    dose_dexa = 0.3;
    LPS_time = 72;
    
    %Scheme1
    X(end) = 0;
    X(end-1) = dose_LPS;
    sim1 = IQMPsimulate(Model, LPS_time, ss_simulation.statevalues(end,:), paramNames, X);
    X(end) = dose_dexa;
    sim2 = IQMPsimulate(Model, 24, sim1.statevalues(end,:), paramNames, X);
    X(end) = dose_dexa+sim2.variablevalues(end,1);
    sim3 = IQMPsimulate(Model, 24, sim2.statevalues(end,:), paramNames, X);
    
    %Scheme3
    X(end) = dose_dexa/3;
    sim4 = IQMPsimulate(Model, 24/3, sim1.statevalues(end,:), paramNames, X);
    X(end) = dose_dexa/3+sim4.variablevalues(end,1);
    sim5 = IQMPsimulate(Model, 24/3, sim4.statevalues(end,:), paramNames, X);
    X(end) = dose_dexa/3+sim5.variablevalues(end,1);
    sim6 = IQMPsimulate(Model, 24/3, sim5.statevalues(end,:), paramNames, X);
    X(end) = dose_dexa/3+sim6.variablevalues(end,1);
    sim41 = IQMPsimulate(Model, 24/3, sim6.statevalues(end,:), paramNames, X);
    X(end) = dose_dexa/3+sim41.variablevalues(end,1);
    sim51 = IQMPsimulate(Model, 24/3, sim41.statevalues(end,:), paramNames, X);
    X(end) = dose_dexa/3+sim51.variablevalues(end,1);
    sim61 = IQMPsimulate(Model, 24/3, sim51.statevalues(end,:), paramNames, X);

    %Scheme2
    X(end) = dose_dexa/2;
    sim7 = IQMPsimulate(Model, 24/2, sim1.statevalues(end,:), paramNames, X);
    X(end) = dose_dexa/2+sim7.variablevalues(end,1);
    sim8 = IQMPsimulate(Model, 24/2, sim7.statevalues(end,:), paramNames, X);
    X(end) = dose_dexa/2+sim8.variablevalues(end,1);
    sim71 = IQMPsimulate(Model, 24/2, sim8.statevalues(end,:), paramNames, X);
    X(end) = dose_dexa/2+sim71.variablevalues(end,1);
    sim81 = IQMPsimulate(Model, 24/2, sim71.statevalues(end,:), paramNames, X);
    
    maxk=24;
    %Scheme4
    X(end) = 0;
    X(end) = dose_dexa/maxk;
    sim(1) = IQMPsimulate(Model, 24/maxk, sim1.statevalues(end,:), paramNames, X);
    for k = 2:maxk
        X(end) = dose_dexa/maxk+sim(k-1).variablevalues(end,1);
        sim(k) = IQMPsimulate(Model, 24/maxk, sim(k-1).statevalues(end,:), paramNames, X);
    end
    X(end) = dose_dexa/maxk+sim(k).variablevalues(end,1);
    simsec(1) = IQMPsimulate(Model, 24/maxk, sim(end).statevalues(end,:), paramNames, X);
    for k = 2:maxk
        X(end) = dose_dexa/maxk+simsec(k-1).variablevalues(end,1);
        simsec(k) = IQMPsimulate(Model, 24/maxk, simsec(k-1).statevalues(end,:), paramNames, X);
    end
    
    if l == 1
        l=2;
        
        %TNF
        sim1_min =  sim1.variablevalues(:,end);
        sim1_max = sim1.variablevalues(:,end);
        sim2_min =  sim2.variablevalues(:,end);
        sim2_max = sim2.variablevalues(:,end);
        sim3_min =  sim3.variablevalues(:,end);
        sim3_max = sim3.variablevalues(:,end);
        sim4_min =  sim4.variablevalues(:,end);
        sim4_max = sim4.variablevalues(:,end);
        sim5_min =  sim5.variablevalues(:,end);
        sim5_max = sim5.variablevalues(:,end);
        sim6_min =  sim6.variablevalues(:,end);
        sim6_max = sim6.variablevalues(:,end);
        sim7_min =  sim7.variablevalues(:,end);
        sim7_max = sim7.variablevalues(:,end);
        sim8_min =  sim8.variablevalues(:,end);
        sim8_max = sim8.variablevalues(:,end);
        sim41_min =  sim41.variablevalues(:,end);
        sim41_max = sim41.variablevalues(:,end);
        sim51_min =  sim51.variablevalues(:,end);
        sim51_max = sim51.variablevalues(:,end);
        sim61_min =  sim61.variablevalues(:,end);
        sim61_max = sim61.variablevalues(:,end);
        sim71_min =  sim71.variablevalues(:,end);
        sim71_max = sim71.variablevalues(:,end);
        sim81_min =  sim81.variablevalues(:,end);
        sim81_max = sim81.variablevalues(:,end);
        sim_min = ones(1001,maxk);
        sim_max = ones(1001,maxk);
        simsec_min = ones(1001,maxk);
        simsec_max = ones(1001,maxk);
        for k = 1:maxk
            sim_min(:,k) = sim(k).variablevalues(:,end);
            sim_max(:,k) = sim(k).variablevalues(:,end);
            simsec_min(:,k) = simsec(k).variablevalues(:,end);
            simsec_max(:,k) = simsec(k).variablevalues(:,end);
        end
        
        %Dexa-GR
        simGR1_min =  sim1.statevalues(:,7);
        simGR1_max = sim1.statevalues(:,7);
        simGR2_min =  sim2.statevalues(:,7);
        simGR2_max = sim2.statevalues(:,7);
        simGR3_min =  sim3.statevalues(:,7);
        simGR3_max = sim3.statevalues(:,7);
        simGR4_min =  sim4.statevalues(:,7);
        simGR4_max = sim4.statevalues(:,7);
        simGR5_min =  sim5.statevalues(:,7);
        simGR5_max = sim5.statevalues(:,7);
        simGR6_min =  sim6.statevalues(:,7);
        simGR6_max = sim6.statevalues(:,7);
        simGR7_min =  sim7.statevalues(:,7);
        simGR7_max = sim7.statevalues(:,7);
        simGR8_min =  sim8.statevalues(:,7);
        simGR8_max = sim8.statevalues(:,7);
        simGR41_min =  sim41.statevalues(:,7);
        simGR41_max = sim41.statevalues(:,7);
        simGR51_min =  sim51.statevalues(:,7);
        simGR51_max = sim51.statevalues(:,7);
        simGR61_min =  sim61.statevalues(:,7);
        simGR61_max = sim61.statevalues(:,7);
        simGR71_min =  sim71.statevalues(:,7);
        simGR71_max = sim71.statevalues(:,7);
        simGR81_min =  sim81.statevalues(:,7);
        simGR81_max = sim81.statevalues(:,7);
        simGR_min = ones(1001,maxk);
        simGR_max = ones(1001,maxk);
        simGRsec_min = ones(1001,maxk);
        simGRsec_max = ones(1001,maxk);
        for k = 1:maxk
            simGR_min(:,k) = sim(k).statevalues(:,7);
            simGR_max(:,k) = sim(k).statevalues(:,7);
            simGRsec_min(:,k) = simsec(k).statevalues(:,7);
            simGRsec_max(:,k) = simsec(k).statevalues(:,7);
        end

    else
        %TNF
        for j = 1:size(sim1_min,1)
            sim1_min(j) = min(sim1.variablevalues(j,end), sim1_min(j));
            sim1_max(j) = max(sim1.variablevalues(j,end), sim1_max(j));
        end
        for j = 1:size(sim2_min,1)
            sim2_min(j) = min(sim2.variablevalues(j,end), sim2_min(j));
            sim2_max(j) = max(sim2.variablevalues(j,end), sim2_max(j));
            sim3_min(j) = min(sim3.variablevalues(j,end), sim3_min(j));
            sim3_max(j) = max(sim3.variablevalues(j,end), sim3_max(j));
        end
        for j = 1:size(sim4_min,1)
            sim4_min(j) = min(sim4.variablevalues(j,end), sim4_min(j));
            sim4_max(j) = max(sim4.variablevalues(j,end), sim4_max(j));
            sim5_min(j) = min(sim5.variablevalues(j,end), sim5_min(j));
            sim5_max(j) = max(sim5.variablevalues(j,end), sim5_max(j));
            sim6_min(j) = min(sim6.variablevalues(j,end), sim6_min(j));
            sim6_max(j) = max(sim6.variablevalues(j,end), sim6_max(j));
            sim41_min(j) = min(sim41.variablevalues(j,end), sim41_min(j));
            sim41_max(j) = max(sim41.variablevalues(j,end), sim41_max(j));
            sim51_min(j) = min(sim51.variablevalues(j,end), sim51_min(j));
            sim51_max(j) = max(sim51.variablevalues(j,end), sim51_max(j));
            sim61_min(j) = min(sim61.variablevalues(j,end), sim61_min(j));
            sim61_max(j) = max(sim61.variablevalues(j,end), sim61_max(j));
        end
        for j = 1:size(sim7_min,1)
            sim7_min(j) = min(sim7.variablevalues(j,end), sim7_min(j));
            sim7_max(j) = max(sim7.variablevalues(j,end), sim7_max(j));
            sim8_min(j) = min(sim8.variablevalues(j,end), sim8_min(j));
            sim8_max(j) = max(sim8.variablevalues(j,end), sim8_max(j));
            sim71_min(j) = min(sim71.variablevalues(j,end), sim71_min(j));
            sim71_max(j) = max(sim71.variablevalues(j,end), sim71_max(j));
            sim81_min(j) = min(sim81.variablevalues(j,end), sim81_min(j));
            sim81_max(j) = max(sim81.variablevalues(j,end), sim81_max(j));        
        end
        for j=1:size(sim_min(:,1),1)
            for k = 1:maxk
                sim_min(j,k) = min(sim(k).variablevalues(j,end), sim_min(j,k));
                sim_max(j,k) = max(sim(k).variablevalues(j,end), sim_max(j,k));
                simsec_min(j,k) = min(simsec(k).variablevalues(j,end), simsec_min(j,k));
                simsec_max(j,k) = max(simsec(k).variablevalues(j,end), simsec_max(j,k));
            end
        end

        %Dexa-GR
        for j = 1:size(simGR1_min,1)
            simGR1_min(j) = min(sim1.statevalues(j,7), simGR1_min(j));
            simGR1_max(j) = max(sim1.statevalues(j,7), simGR1_max(j));
        end
        for j = 1:size(simGR2_min,1)
            simGR2_min(j) = min(sim2.statevalues(j,7), simGR2_min(j));
            simGR2_max(j) = max(sim2.statevalues(j,7), simGR2_max(j));
            simGR3_min(j) = min(sim3.statevalues(j,7), simGR3_min(j));
            simGR3_max(j) = max(sim3.statevalues(j,7), simGR3_max(j));
        end
        for j = 1:size(simGR4_min,1)
            simGR4_min(j) = min(sim4.statevalues(j,7), simGR4_min(j));
            simGR4_max(j) = max(sim4.statevalues(j,7), simGR4_max(j));
            simGR5_min(j) = min(sim5.statevalues(j,7), simGR5_min(j));
            simGR5_max(j) = max(sim5.statevalues(j,7), simGR5_max(j));
            simGR6_min(j) = min(sim6.statevalues(j,7), simGR6_min(j));
            simGR6_max(j) = max(sim6.statevalues(j,7), simGR6_max(j));
            simGR41_min(j) = min(sim41.statevalues(j,7), simGR41_min(j));
            simGR41_max(j) = max(sim41.statevalues(j,7), simGR41_max(j));
            simGR51_min(j) = min(sim51.statevalues(j,7), simGR51_min(j));
            simGR51_max(j) = max(sim51.statevalues(j,7), simGR51_max(j));
            simGR61_min(j) = min(sim61.statevalues(j,7), simGR61_min(j));
            simGR61_max(j) = max(sim61.statevalues(j,7), simGR61_max(j));
        end
        for j = 1:size(simGR7_min,1)
            simGR7_min(j) = min(sim7.statevalues(j,7), simGR7_min(j));
            simGR7_max(j) = max(sim7.statevalues(j,7), simGR7_max(j));
            simGR8_min(j) = min(sim8.statevalues(j,7), simGR8_min(j));
            simGR8_max(j) = max(sim8.statevalues(j,7), simGR8_max(j));
            simGR71_min(j) = min(sim71.statevalues(j,7), simGR71_min(j));
            simGR71_max(j) = max(sim71.statevalues(j,7), simGR71_max(j));
            simGR81_min(j) = min(sim81.statevalues(j,7), simGR81_min(j));
            simGR81_max(j) = max(sim81.statevalues(j,7), simGR81_max(j));        
        end
        for j=1:size(simGR_min(:,1),1)
            for k = 1:maxk
                simGR_min(j,k) = min(sim(k).statevalues(j,7), simGR_min(j,k));
                simGR_max(j,k) = max(sim(k).statevalues(j,7), simGR_max(j,k));
                simGRsec_min(j,k) = min(simsec(k).statevalues(j,7), simGRsec_min(j,k));
                simGRsec_max(j,k) = max(simsec(k).statevalues(j,7), simGRsec_max(j,k));
            end
        end
    
    end
     
end

%% Compute and print AUC

format short
AUC1min_sec = trapz(1:24/1000:25,sim3_min-min(sim2_min))
AUC1max_sec = trapz(1:24/1000:25,sim3_max-min(sim2_min))
AUC2min_sec = trapz([1:12/1000:13 13:12/1000:25],[sim71_min-min(sim2_min); sim81_min-min(sim2_min)])
AUC2max_sec = trapz([1:12/1000:13 13:12/1000:25],[sim71_max-min(sim2_min); sim81_max-min(sim2_min)])
AUC3min_sec = trapz([1:8/1000:9 9:8/1000:17 17:8/1000:25],[sim51_min-min(sim2_min); sim61_min-min(sim2_min); sim71_min-min(sim2_min)])
AUC3max_sec = trapz([1:8/1000:9 9:8/1000:17 17:8/1000:25],[sim51_max-min(sim2_min); sim61_max-min(sim2_min); sim71_max-min(sim2_min)])

AUC4min_sec = 0;
AUC4max_sec = 0;
for k=1:maxk
    AUC4min_sec = AUC4min_sec + trapz(1+24/maxk*(k-1):(24/maxk)/1000:1+24/maxk*k, simsec_min(:,k)-min(sim2_min));
    AUC4max_sec = AUC4max_sec + trapz(1+24/maxk*(k-1):(24/maxk)/1000:1+24/maxk*k, simsec_max(:,k)-min(sim2_min));
end
AUC4min_sec
AUC4max_sec

LPS_time = 1;

%% PLOT
figure(11)
subplot(4,1,1)
hold on
h=fill([0:1/10:1, flip(0:1/10:1)],[sim1_min(end-10:end); flip(sim1_max(end-10:end))]', LPS100);
set(h,'facealpha',.9,'EdgeColor','none')
h=fill([LPS_time:24/1000:24+LPS_time, flip(LPS_time:24/1000:24+LPS_time)],[sim2_min; flip(sim2_max)]',  dexa3_pre1);
set(h,'facealpha',.9,'EdgeColor','none')
h=fill([LPS_time+24:24/1000:48+LPS_time, flip(LPS_time+24:24/1000:48+LPS_time)],[sim3_min; flip(sim3_max)]',  dexa03_pre);
set(h,'facealpha',.9,'EdgeColor','none')
plot([0,49],[min(sim2_min),min(sim2_min)],'-k')
plot([0,49],[sim2_max(end),sim2_max(end)],'-k')
plot([25,25],[0,4],'-k')
plot([1,1],[0,4],'-k')
title('One treatment per day');
xlabel('Time (hours)');
ylabel('TNF, a.u.');
set(gca,'FontSize',14);
axis([0,LPS_time+48,0,sim1_max(end-10)+0.01])

subplot(4,1,2)
hold on
h=fill([0:1/10:1, flip(0:1/10:1)],[sim1_min(end-10:end); flip(sim1_max(end-10:end))]', LPS100);
set(h,'facealpha',.9,'EdgeColor','none')
h=fill([1:12/1000:13, flip(1:12/1000:13)],[sim7_min; flip(sim7_max)]',  dexa3_pre1);
set(h,'facealpha',.9,'EdgeColor','none')
h=fill([13:12/1000:25, flip(13:12/1000:25)],[sim8_min; flip(sim8_max)]',  dexa3_pre1);
set(h,'facealpha',.9,'EdgeColor','none')
h=fill([25:12/1000:37, flip(25:12/1000:37)],[sim71_min; flip(sim71_max)]',  dexa03_pre);
set(h,'facealpha',.9,'EdgeColor','none')
h=fill([37:12/1000:49, flip(37:12/1000:49)],[sim81_min; flip(sim81_max)]',  dexa03_pre);
set(h,'facealpha',.9,'EdgeColor','none')
plot([0,49],[min(sim2_min),min(sim2_min)],'-k')
plot([0,49],[sim2_max(end),sim2_max(end)],'-k')
plot([25,25],[0,4],'-k')
plot([1,1],[0,4],'-k')
title('Two treatments per day');
xlabel('Time (hours)');
ylabel('TNF, a.u.');
set(gca,'FontSize',14);
axis([0,49,0,sim1_max(end-10)+0.01])

subplot(4,1,3)
hold on
h=fill([0:1/10:1, flip(0:1/10:1)],[sim1_min(end-10:end); flip(sim1_max(end-10:end))]', LPS100);
set(h,'facealpha',.9,'EdgeColor','none')
h=fill([1:8/1000:9, flip(1:8/1000:9)],[sim4_min; flip(sim4_max)]',  dexa3_pre1);
set(h,'facealpha',.9,'EdgeColor','none')
h=fill([9:8/1000:17, flip(9:8/1000:17)],[sim5_min; flip(sim5_max)]',  dexa3_pre1);
set(h,'facealpha',.9,'EdgeColor','none')
h=fill([17:8/1000:25, flip(17:8/1000:25)],[sim6_min; flip(sim6_max)]',  dexa3_pre1);
set(h,'facealpha',.9,'EdgeColor','none')
h=fill([25:8/1000:33, flip(25:8/1000:33)],[sim41_min; flip(sim41_max)]',  dexa03_pre);
set(h,'facealpha',.9,'EdgeColor','none')
h=fill([33:8/1000:41, flip(33:8/1000:41)],[sim51_min; flip(sim51_max)]',  dexa03_pre);
set(h,'facealpha',.9,'EdgeColor','none')
h=fill([41:8/1000:49, flip(41:8/1000:49)],[sim61_min; flip(sim61_max)]',  dexa03_pre);
set(h,'facealpha',.9,'EdgeColor','none')
plot([0,49],[min(sim2_min),min(sim2_min)],'-k')
plot([0,49],[sim2_max(end),sim2_max(end)],'-k')
plot([25,25],[0,4],'-k')
plot([1,1],[0,4],'-k')
title('Three treatments per day');
xlabel('Time (hours)');
ylabel('TNF, a.u.');
set(gca,'FontSize',14);
axis([0,49,0,sim1_max(end-10)+0.01])

subplot(4,1,4)
hold on
h=fill([0:1/10:1, flip(0:1/10:1)],[sim1_min(end-10:end); flip(sim1_max(end-10:end))]', LPS100);
set(h,'facealpha',.9,'EdgeColor','none')
for k=1:maxk
    h=fill([1+24/maxk*(k-1):(24/maxk)/1000:1+24/maxk*k, flip(1+24/maxk*(k-1):(24/maxk)/1000:1+24/maxk*k)],[sim_min(:,k); flip(sim_max(:,k))]', dexa3_pre1);
    set(h,'facealpha',.9,'EdgeColor','none')
end
for k=1:maxk
    h=fill([25+24/maxk*(k-1):(24/maxk)/1000:25+24/maxk*k, flip(25+24/maxk*(k-1):(24/maxk)/1000:25+24/maxk*k)],[simsec_min(:,k); flip(simsec_max(:,k))]', dexa03_pre);
    set(h,'facealpha',.9,'EdgeColor','none')
end
plot([0,49],[min(sim2_min),min(sim2_min)],'-k')
plot([0,49],[sim2_max(end),sim2_max(end)],'-k')
plot([25,25],[0,4],'-k')
plot([1,1],[0,4],'-k')
title('24 treatments per day');
xlabel('Time (hours)');
ylabel('TNF, a.u.');
set(gca,'FontSize',14);
axis([0,49,0,sim1_max(end-10)+0.01])

figure(12)
subplot(4,1,1)
hold on
h=fill([0:1/10:1, flip(0:1/10:1)],[simGR1_min(end-10:end); flip(simGR1_max(end-10:end))]', LPS100);
set(h,'facealpha',.9,'EdgeColor','none')
h=fill([LPS_time:24/1000:24+LPS_time, flip(LPS_time:24/1000:24+LPS_time)],[simGR2_min; flip(simGR2_max)]',  dexa3_pre1);
set(h,'facealpha',.9,'EdgeColor','none')
h=fill([LPS_time+24:24/1000:48+LPS_time, flip(LPS_time+24:24/1000:48+LPS_time)],[simGR3_min; flip(simGR3_max)]',  dexa03_pre);
set(h,'facealpha',.9,'EdgeColor','none')
plot([25,25],[0,4],'-k')
plot([1,1],[0,4],'-k')
title('One treatment per day');
xlabel('Time (hours)');
ylabel('Dexa-GR, a.u.');
set(gca,'FontSize',14);
axis([0,LPS_time+48,0,max(simGR3_max)+0.01])

subplot(4,1,2)
hold on
h=fill([0:1/10:1, flip(0:1/10:1)],[simGR1_min(end-10:end); flip(simGR1_max(end-10:end))]', LPS100);
set(h,'facealpha',.9,'EdgeColor','none')
h=fill([1:12/1000:13, flip(1:12/1000:13)],[simGR7_min; flip(simGR7_max)]',  dexa3_pre1);
set(h,'facealpha',.9,'EdgeColor','none')
h=fill([13:12/1000:25, flip(13:12/1000:25)],[simGR8_min; flip(simGR8_max)]',  dexa3_pre1);
set(h,'facealpha',.9,'EdgeColor','none')
h=fill([25:12/1000:37, flip(25:12/1000:37)],[simGR71_min; flip(simGR71_max)]',  dexa03_pre);
set(h,'facealpha',.9,'EdgeColor','none')
h=fill([37:12/1000:49, flip(37:12/1000:49)],[simGR81_min; flip(simGR81_max)]',  dexa03_pre);
set(h,'facealpha',.9,'EdgeColor','none')
plot([25,25],[0,4],'-k')
plot([1,1],[0,4],'-k')
title('Two treatments per day');
xlabel('Time (hours)');
ylabel('Dexa-GR, a.u.');
set(gca,'FontSize',14);
axis([0,49,0,max(simGR3_max)+0.01])

subplot(4,1,3)
hold on
h=fill([0:1/10:1, flip(0:1/10:1)],[simGR1_min(end-10:end); flip(simGR1_max(end-10:end))]', LPS100);
%h=fill([0:1/1000.001:1, flip(0:1/1000:1)],[simGR1_min; flip(simGR1_max)]', LPS100);
set(h,'facealpha',.9,'EdgeColor','none')
h=fill([1:8/1000:9, flip(1:8/1000:9)],[simGR4_min; flip(simGR4_max)]',  dexa3_pre1);
set(h,'facealpha',.9,'EdgeColor','none')
h=fill([9:8/1000:17, flip(9:8/1000:17)],[simGR5_min; flip(simGR5_max)]',  dexa3_pre1);
set(h,'facealpha',.9,'EdgeColor','none')
h=fill([17:8/1000:25, flip(17:8/1000:25)],[simGR6_min; flip(simGR6_max)]',  dexa3_pre1);
set(h,'facealpha',.9,'EdgeColor','none')
h=fill([25:8/1000:33, flip(25:8/1000:33)],[simGR41_min; flip(simGR41_max)]',  dexa03_pre);
set(h,'facealpha',.9,'EdgeColor','none')
h=fill([33:8/1000:41, flip(33:8/1000:41)],[simGR51_min; flip(simGR51_max)]',  dexa03_pre);
set(h,'facealpha',.9,'EdgeColor','none')
h=fill([41:8/1000:49, flip(41:8/1000:49)],[simGR61_min; flip(simGR61_max)]',  dexa03_pre);
set(h,'facealpha',.9,'EdgeColor','none')
plot([25,25],[0,4],'-k')
plot([1,1],[0,4],'-k')
title('Three treatments per day');
xlabel('Time (hours)');
ylabel('Dexa-GR, a.u.');
set(gca,'FontSize',14);
axis([0,49,0,max(simGR3_max)+0.01])

subplot(4,1,4)
hold on
h=fill([0:1/10:1, flip(0:1/10:1)],[simGR1_min(end-10:end); flip(simGR1_max(end-10:end))]', LPS100);
set(h,'facealpha',.9,'EdgeColor','none')
for k=1:maxk
    h=fill([1+24/maxk*(k-1):(24/maxk)/1000:1+24/maxk*k, flip(1+24/maxk*(k-1):(24/maxk)/1000:1+24/maxk*k)],[simGR_min(:,k); flip(simGR_max(:,k))]', dexa3_pre1);
    set(h,'facealpha',.9,'EdgeColor','none')
end
for k=1:maxk
    h=fill([25+24/maxk*(k-1):(24/maxk)/1000:25+24/maxk*k, flip(25+24/maxk*(k-1):(24/maxk)/1000:25+24/maxk*k)],[simGRsec_min(:,k); flip(simGRsec_max(:,k))]', dexa03_pre);
    set(h,'facealpha',.9,'EdgeColor','none')
end
plot([25,25],[0,4],'-k')
plot([1,1],[0,4],'-k')
title('24 treatments per day');
xlabel('Time (hours)');
ylabel('Dexa-GR, a.u.');
set(gca,'FontSize',14);
axis([0,49,0,max(simGR3_max)+0.01])

figure(2)
subplot(4,1,1)
plot(0:0.1:1, sim1.statevalues(end-10:end,7), 'Color', LPS100, 'LineWidth', 2)
hold on
plot(1:24/1000:25, sim2.statevalues(:,7),  'Color', dexa3_pre1, 'LineWidth', 2)
plot(25:24/1000:49, sim3.statevalues(:,7),  'Color', dexa03_pre, 'LineWidth', 2)
plot([25,25],[0,max(sim3.statevalues(:,7))+dose_dexa/10],'-k')
plot([1,1],[0,max(sim3.statevalues(:,7))+dose_dexa/10],'-k')
title('One treatment per day');
xlabel('Time (hours)');
ylabel('Dexa-GR');
set(gca,'FontSize',14);
box off
subplot(4,1,2)
plot(0:0.1:1, sim1.statevalues(end-10:end,7), 'Color', LPS100, 'LineWidth', 2)
hold on
plot(1:12/1000:13, sim7.statevalues(:,7),  'Color', dexa3_pre1, 'LineWidth', 2)
plot(13:12/1000:25, sim8.statevalues(:,7),  'Color', dexa3_pre1, 'LineWidth', 2)
plot(25:12/1000:37, sim71.statevalues(:,7),  'Color', dexa03_pre, 'LineWidth', 2)
plot(37:12/1000:49, sim81.statevalues(:,7),  'Color', dexa03_pre, 'LineWidth', 2)
plot([25,25],[0,max(sim3.statevalues(:,7))+dose_dexa/10],'-k')
plot([1,1],[0,max(sim3.statevalues(:,7))+dose_dexa/10],'-k')
title('Two treatments per day');
xlabel('Time (hours)');
ylabel('Dexa-GR');
set(gca,'FontSize',14);
box off
subplot(4,1,3)
plot(0:0.1:1, sim1.statevalues(end-10:end,7), 'Color', LPS100, 'LineWidth', 2)
hold on
plot(1:8/1000:9, sim4.statevalues(:,7),  'Color', dexa3_pre1, 'LineWidth', 2)
plot(9:8/1000:17, sim5.statevalues(:,7),  'Color', dexa3_pre1, 'LineWidth', 2)
plot(17:8/1000:25, sim6.statevalues(:,7),  'Color', dexa3_pre1, 'LineWidth', 2)
plot(25:8/1000:33, sim41.statevalues(:,7),  'Color', dexa03_pre, 'LineWidth', 2)
plot(33:8/1000:41, sim51.statevalues(:,7),  'Color', dexa03_pre, 'LineWidth', 2)
plot(41:8/1000:49, sim61.statevalues(:,7),  'Color', dexa03_pre, 'LineWidth', 2)
plot([25,25],[0,max(sim3.statevalues(:,7))+dose_dexa/10],'-k')
plot([1,1],[0,max(sim3.statevalues(:,7))+dose_dexa/10],'-k')
title('Three treatments per day');
xlabel('Time (hours)');
ylabel('Dexa-GR');
set(gca,'FontSize',14);
box off
subplot(4,1,4)
plot(0:0.1:1, sim1.statevalues(end-10:end,7), 'Color', LPS100, 'LineWidth', 2)
hold on
for k=1:maxk
    plot(1+24/maxk*(k-1):(24/maxk)/1000:1+24/maxk*k, sim(k).statevalues(:,7),  'Color', dexa3_pre1, 'LineWidth', 2)
end
for k=1:maxk
    plot(25+24/maxk*(k-1):(24/maxk)/1000:25+24/maxk*k, simsec(k).statevalues(:,7),  'Color', dexa03_pre, 'LineWidth', 2)
end
plot([25,25],[0,max(sim3.statevalues(:,7))+dose_dexa/10],'-k')
plot([1,1],[0,max(sim3.statevalues(:,7))+dose_dexa/10],'-k')
title('24 treatments per day');
xlabel('Time (hours)');
ylabel('Dexa-GR');
set(gca,'FontSize',14);
box off

figure(3)
subplot(4,1,1)
plot(0:0.1:1, sim1.statevalues(end-10:end,7), 'Color', LPS100, 'LineWidth', 2)
hold on
plot(1:24/1000:25, sim2.variablevalues(:,1),  'Color', dexa3_pre1, 'LineWidth', 2)
plot(25:24/1000:49, sim3.variablevalues(:,1),  'Color', dexa03_pre, 'LineWidth', 2)
plot([25,25],[0,dose_dexa],'-k')
plot([1,1],[0,dose_dexa],'-k')
title('One treatment per day');
xlabel('Time (hours)');
ylabel('Dexa, a.u.');
set(gca,'FontSize',14);
box off
subplot(4,1,2)
plot(0:0.1:1, sim1.statevalues(end-10:end,7), 'Color', LPS100, 'LineWidth', 2)
hold on
plot(1:12/1000:13, sim7.variablevalues(:,1),  'Color', dexa3_pre1, 'LineWidth', 2)
plot(13:12/1000:25, sim8.variablevalues(:,1),  'Color', dexa3_pre1, 'LineWidth', 2)
plot(25:12/1000:37, sim71.variablevalues(:,1),  'Color', dexa03_pre, 'LineWidth', 2)
plot(37:12/1000:49, sim81.variablevalues(:,1),  'Color', dexa03_pre, 'LineWidth', 2)
plot([25,25],[0,dose_dexa],'-k')
plot([1,1],[0,dose_dexa],'-k')
title('Two treatments per day');
xlabel('Time (hours)');
ylabel('Dexa, a.u.');
set(gca,'FontSize',14);
box off
subplot(4,1,3)
plot(0:0.1:1, sim1.statevalues(end-10:end,7), 'Color', LPS100, 'LineWidth', 2)
hold on
plot(1:8/1000:9, sim4.variablevalues(:,1),  'Color', dexa3_pre1, 'LineWidth', 2)
plot(9:8/1000:17, sim5.variablevalues(:,1),  'Color', dexa3_pre1, 'LineWidth', 2)
plot(17:8/1000:25, sim6.variablevalues(:,1),  'Color', dexa3_pre1, 'LineWidth', 2)
plot(25:8/1000:33, sim41.variablevalues(:,1),  'Color', dexa03_pre, 'LineWidth', 2)
plot(33:8/1000:41, sim51.variablevalues(:,1),  'Color', dexa03_pre, 'LineWidth', 2)
plot(41:8/1000:49, sim61.variablevalues(:,1),  'Color', dexa03_pre, 'LineWidth', 2)
plot([25,25],[0,dose_dexa],'-k')
plot([1,1],[0,dose_dexa],'-k')
title('Three treatments per day');
xlabel('Time (hours)');
ylabel('Dexa, a.u.');
set(gca,'FontSize',14);
box off
subplot(4,1,4)
plot(0:0.1:1, sim1.statevalues(end-10:end,7), 'Color', LPS100, 'LineWidth', 2)
hold on
for k=1:maxk
    plot(1+24/maxk*(k-1):(24/maxk)/1000:1+24/maxk*k, sim(k).variablevalues(:,1),  'Color', dexa3_pre1, 'LineWidth', 2)
end
for k=1:maxk
    plot(25+24/maxk*(k-1):(24/maxk)/1000:25+24/maxk*k, simsec(k).variablevalues(:,1),  'Color', dexa03_pre, 'LineWidth', 2)
end
plot([25,25],[0,dose_dexa],'-k')
plot([1,1],[0,dose_dexa],'-k')
title('24 treatments per day');
xlabel('Time (hours)');
ylabel('Dexa, a.u.');
set(gca,'FontSize',14);
box off